@@ -14,11 +14,11 @@ def _prefixed(level, message):
 counter = 0
 
 
-while True:
+while os.getppid() != 1:
     try:
         line = sys.stdin.readline().strip()
         sys.stdout.flush()
-        if line == "":
+        if line == '':
             counter += 1
             if counter > 100:
                 break
@@ -29,6 +29,6 @@ while True:
         sys.stderr.write(_prefixed(sys.argv[1] if len(sys.argv) >= 2 else 'EXABGP PROCESS', line))
     except KeyboardInterrupt:
         pass
-    except IOError:
+    except OSError:
         # most likely a signal during readline
         pass
